aboutsummaryrefslogtreecommitdiff
path: root/src/profiling/RegisterBackendCounters.hpp
diff options
context:
space:
mode:
authorCathal Corbett <cathal.corbett@arm.com>2022-02-25 15:33:28 +0000
committerCathal Corbett <cathal.corbett@arm.com>2022-03-01 11:44:14 +0000
commit5aa9fd7ac6bf8dad576fa4a0a32aa3dae98d11ab (patch)
tree23a3a0d5ca5143924277f34c98d36cf7b99430a7 /src/profiling/RegisterBackendCounters.hpp
parent1fc448ad2455ad31b96a3891f847125a3295d75a (diff)
downloadarmnn-5aa9fd7ac6bf8dad576fa4a0a32aa3dae98d11ab.tar.gz
IVGCVSW-6704 Change the namespace from armnn::profiling to arm::pipe
* Updated ABI version to 29 due to being the first ABI break in 22.05 !android-nn-driver:7226 Signed-off-by: Cathal Corbett <cathal.corbett@arm.com> Change-Id: I9c50007dcd5b5e792757e7bd1213606df5ffec36
Diffstat (limited to 'src/profiling/RegisterBackendCounters.hpp')
-rw-r--r--src/profiling/RegisterBackendCounters.hpp25
1 files changed, 13 insertions, 12 deletions
diff --git a/src/profiling/RegisterBackendCounters.hpp b/src/profiling/RegisterBackendCounters.hpp
index f81f487472..f25feb5306 100644
--- a/src/profiling/RegisterBackendCounters.hpp
+++ b/src/profiling/RegisterBackendCounters.hpp
@@ -10,10 +10,10 @@
#include "CounterDirectory.hpp"
#include "ProfilingService.hpp"
-namespace armnn
+namespace arm
{
-namespace profiling
+namespace pipe
{
class RegisterBackendCounters : public IRegisterBackendCounters
@@ -21,7 +21,7 @@ class RegisterBackendCounters : public IRegisterBackendCounters
public:
RegisterBackendCounters(
- uint16_t currentMaxGlobalCounterID, const BackendId& backendId, ProfilingService& profilingService)
+ uint16_t currentMaxGlobalCounterID, const armnn::BackendId& backendId, ProfilingService& profilingService)
: m_CurrentMaxGlobalCounterID(currentMaxGlobalCounterID),
m_BackendId(backendId),
m_ProfilingService(profilingService),
@@ -33,11 +33,12 @@ public:
uint16_t RegisterDevice(const std::string& deviceName,
uint16_t cores = 0,
- const Optional<std::string>& parentCategoryName = EmptyOptional()) override;
+ const armnn::Optional<std::string>& parentCategoryName = armnn::EmptyOptional()) override;
uint16_t RegisterCounterSet(const std::string& counterSetName,
uint16_t count = 0,
- const Optional<std::string>& parentCategoryName = EmptyOptional()) override;
+ const armnn::Optional<std::string>& parentCategoryName
+ = armnn::EmptyOptional()) override;
uint16_t RegisterCounter(const uint16_t uid,
const std::string& parentCategoryName,
@@ -46,18 +47,18 @@ public:
double multiplier,
const std::string& name,
const std::string& description,
- const Optional<std::string>& units = EmptyOptional(),
- const Optional<uint16_t>& numberOfCores = EmptyOptional(),
- const Optional<uint16_t>& deviceUid = EmptyOptional(),
- const Optional<uint16_t>& counterSetUid = EmptyOptional()) override;
+ const armnn::Optional<std::string>& units = armnn::EmptyOptional(),
+ const armnn::Optional<uint16_t>& numberOfCores = armnn::EmptyOptional(),
+ const armnn::Optional<uint16_t>& deviceUid = armnn::EmptyOptional(),
+ const armnn::Optional<uint16_t>& counterSetUid = armnn::EmptyOptional()) override;
private:
uint16_t m_CurrentMaxGlobalCounterID;
- const BackendId& m_BackendId;
+ const armnn::BackendId& m_BackendId;
ProfilingService& m_ProfilingService;
ICounterRegistry& m_CounterDirectory;
};
-} // namespace profiling
+} // namespace pipe
-} // namespace armnn \ No newline at end of file
+} // namespace arm \ No newline at end of file